AppInfoProvider class
- Inheritance
-
- Object
- FirebaseDocProvider<
AppInfoDoc> - AppInfoProvider
Constructors
- AppInfoProvider({required String listenNode, required Version appVersion, required Directory apkDir})
Properties
- apkAvalable ↔ bool
-
getter/setter pair
- appVersion → Version
-
final
- cancleOnError → bool Function(Object error)?
-
finalinherited
- currentVersion → Version
-
no setter
- doc → AppInfoDoc?
-
no setterinherited
- downloading ↔ bool
-
getter/setter pair
- error → Object?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isNew → bool
-
no setter
- loading → bool
-
no setterinherited
- parse → AppInfoDoc Function(RawMap data)
-
finalinherited
- path → String?
-
no setteroverride
- progress ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageInstance → FirebaseStorage
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
convertor(
Map< String, Object?> ? data) → AppInfoDoc? -
override
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
download(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
openApk(
) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited