RawObj class

Constructors

RawObj(Object? data)

Properties

data Object?
final
hashCode int
The hash code for this object.
no setterinherited
nullOr RawObj?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBool() bool
toDateTimeString() DateTimeString
toInt() int
toIntMoney() IntMoney
toIntQuntity() IntQuntity
toItrable() Iterable<RawObj>
toMap() RawMap
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

nullable(Object? data) RawObj?
toNullableRawMap(Map<String, Object?> data) Map<String, RawObj?>