DisplaySelectRow<T> class

Constructors

DisplaySelectRow({required Set<T> selected, required void onSelectChange(T, bool)})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onSelectChange → void Function(T, bool)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → Set<T>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited